@@ -1,15 +1,14 @@
 
+from nose2.tools.decorators import with_setup, with_teardown
 from smb.SMBConnection import SMBConnection
-from smb.smb2_constants import SMB2_DIALECT_2
-from .util import getConnectionInfo
-from nose.tools import with_setup
 from smb import smb_structs
+from .util import getConnectionInfo
 
 conn = None
 
 def setup_func_SMB1():
     global conn
-    smb_structs.SUPPORT_SMB2 = smb_structs.SUPPORT_SMB2x = False
+    smb_structs.SUPPORT_SMB2 = False
     info = getConnectionInfo()
     conn = SMBConnection(info['user'], info['password'], info['client_name'], info['server_name'], use_ntlm_v2 = True)
     assert conn.connect(info['server_ip'], info['server_port'])
@@ -17,14 +16,6 @@ def setup_func_SMB1():
 def setup_func_SMB2():
     global conn
     smb_structs.SUPPORT_SMB2 = True
-    smb_structs.SUPPORT_SMB2x = False
-    info = getConnectionInfo()
-    conn = SMBConnection(info['user'], info['password'], info['client_name'], info['server_name'], use_ntlm_v2 = True)
-    assert conn.connect(info['server_ip'], info['server_port'])
-
-def setup_func_SMB2x():
-    global conn
-    smb_structs.SUPPORT_SMB2 = smb_structs.SUPPORT_SMB2x = True
     info = getConnectionInfo()
     conn = SMBConnection(info['user'], info['password'], info['client_name'], info['server_name'], use_ntlm_v2 = True)
     assert conn.connect(info['server_ip'], info['server_port'])
@@ -33,22 +24,16 @@ def teardown_func():
     global conn
     conn.close()
 
-@with_setup(setup_func_SMB1, teardown_func)
+@with_setup(setup_func_SMB1)
+@with_teardown(teardown_func)
 def test_listshares_SMB1():
     global conn
     results = conn.listShares()
-    assert 'smbtest' in list(map(lambda r: r.name.lower(), results))
+    assert 'smbtest' in [r.name.lower() for r in results]
 
-@with_setup(setup_func_SMB2, teardown_func)
+@with_setup(setup_func_SMB2)
+@with_teardown(teardown_func)
 def test_listshares_SMB2():
     global conn
-    assert conn.smb2_dialect == SMB2_DIALECT_2
     results = conn.listShares()
-    assert 'smbtest' in list(map(lambda r: r.name.lower(), results))
-
-@with_setup(setup_func_SMB2x, teardown_func)
-def test_listshares_SMB2x():
-    global conn
-    assert conn.smb2_dialect != SMB2_DIALECT_2
-    results = conn.listShares()
-    assert 'smbtest' in list(map(lambda r: r.name.lower(), results))
+    assert 'smbtest' in [r.name.lower() for r in results]
